﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Silanis.ESL.SDK;
using Silanis.ESL.SDK.Builder;
using System.Diagnostics;

namespace esl
{
    class DocumentVisibility
    {
        private readonly static string DOC1_ID = "doc1";
        private readonly static string DOC2_ID = "doc2";

        private readonly static string SIGNER1_ID = "Signer1";
        private readonly static string SIGNER2_ID = "Signer2";

        public static void main()
        {

            EslClient eslClient = new EslClient(Properties.Settings.Default.key, Properties.Settings.Default.url);

            DocumentPackage superDuperPackage = PackageBuilder.NewPackageNamed("DocumentVisibilityExample " + DateTime.Now)
                    .DescribedAs("This is a package created using the eSignLive SDK")
                    .WithSigner(SignerBuilder.NewSignerWithEmail("mail31@mailinator.com")
                                    .WithCustomId(SIGNER1_ID)
                                    .WithFirstName("John1")
                                    .WithLastName("Smith1"))
                    .WithSigner(SignerBuilder.NewSignerWithEmail("mail32@mailinator.com")
                                    .WithCustomId(SIGNER2_ID)
                                    .WithFirstName("John2")
                                    .WithLastName("Smith2"))
                    .WithDocument(DocumentBuilder.NewDocumentNamed("Document1")
                                      .WithId(DOC1_ID)
                                      .FromFile("C:/Users/hhaidary/Desktop/PDFs/sample_contract.pdf")
                                      .WithSignature(SignatureBuilder.SignatureFor("mail31@mailinator.com")
                                                         .OnPage(0)
                                                         .AtPosition(100, 100)))
                    .WithDocument(DocumentBuilder.NewDocumentNamed("Document2")
                                      .WithId(DOC2_ID)
                                      .FromFile("C:/Users/hhaidary/Desktop/PDFs/cleaning_contract.pdf")
                                      .WithSignature(SignatureBuilder.SignatureFor("mail32@mailinator.com")
                                                         .OnPage(0)
                                                         .AtPosition(100, 100)))
                    .Build();

            PackageId packageId = eslClient.CreatePackage(superDuperPackage);

            //Create list of signers for visibility of first document. 
            List<string> signerIdsList1 = new List<string>();
            signerIdsList1.Add(SIGNER1_ID);

            //Create list of signers for visibility of second document.
            List<String> signerIdsList2 = new List<string>();
            signerIdsList2.Add(SIGNER2_ID);

            Silanis.ESL.SDK.DocumentVisibility visibility = DocumentVisibilityBuilder.NewDocumentVisibility()
                .AddConfiguration(DocumentVisibilityConfigurationBuilder.NewDocumentVisibilityConfiguration(DOC1_ID)
                        .WithSignerIds(signerIdsList1))
                .AddConfiguration(DocumentVisibilityConfigurationBuilder.NewDocumentVisibilityConfiguration(DOC2_ID)
                        .WithSignerIds(signerIdsList2))
                .Build();

            //Configure document visibility.
            eslClient.ConfigureDocumentVisibility(packageId, visibility);

            eslClient.SendPackage(packageId);

            Debug.WriteLine(packageId);
        }
    }
}
